import { BasicColumn, FormSchema } from '/@/components/Table'
import { getTenantId } from '/@/utils/auth'
import { rules } from '/@/utils/helper/validator'
//列表数据
export const columns: BasicColumn[] = [
  {
    title: '工单时间',
    align: 'center',
    sorter: true,
    dataIndex: 'orderTime',
    customRender: ({ text }) => {
      return !text ? '' : text.length > 10 ? text.substr(0, 10) : text
    },
  },
  {
    title: '工单号',
    align: 'center',
    dataIndex: 'code',
  },
  {
    title: '药材',
    align: 'center',
    dataIndex: 'herbId_dictText',
  },
  {
    title: '初始含水率',
    align: 'center',
    dataIndex: 'initial',
  },
  {
    title: '目标含水率',
    align: 'center',
    dataIndex: 'target',
  },
  {
    title: '投料量',
    align: 'center',
    dataIndex: 'feed',
  },
  {
    title: '预计干燥时间',
    align: 'center',
    dataIndex: 'et',
  },
  {
    title: '干料重量',
    align: 'center',
    dataIndex: 'yield',
  },
  {
    title: '干燥时间',
    align: 'center',
    dataIndex: 'drying',
  },
  {
    title: '预计剩余时间',
    align: 'center',
    dataIndex: 'remain',
  },
  {
    title: '设备',
    align: 'center',
    dataIndex: 'equId_dictText',
  },
  {
    title: '车间',
    align: 'center',
    dataIndex: 'shopId_dictText',
  },
  {
    title: '工单状态',
    align: 'center',
    dataIndex: 'orderStatus',
  },
  {
    title: '操作人',
    align: 'center',
    dataIndex: 'operator_dictText',
  },
]
//查询数据
export const searchFormSchema: FormSchema[] = []
//表单数据
export const formSchema: FormSchema[] = [
  {
    label: '工单时间',
    field: 'orderTime',
    component: 'DatePicker',
  },
  {
    label: '工单号',
    field: 'code',
    component: 'Input',
    dynamicRules: ({ model, schema }) => {
      return [{ required: false }, { ...rules.duplicateCheckRule('dry_order', 'code', model, schema)[0] }]
    },
  },
  {
    label: '药材',
    field: 'herbId',
    component: 'JDictSelectTag',
    componentProps: {
      dictCode: 'dry_herb,name,id,tenant_id=' + getTenantId(),
    },
  },
  {
    label: '初始含水率',
    field: 'initial',
    component: 'InputNumber',
  },
  {
    label: '目标含水率',
    field: 'target',
    component: 'InputNumber',
  },
  {
    label: '投料量',
    field: 'feed',
    component: 'InputNumber',
  },
  {
    label: '预计干燥时间',
    field: 'et',
    component: 'InputNumber',
  },
  {
    label: '干料重量',
    field: 'yield',
    component: 'InputNumber',
  },
  {
    label: '干燥时间',
    field: 'drying',
    component: 'InputNumber',
  },
  {
    label: '预计剩余时间',
    field: 'remain',
    component: 'InputNumber',
  },
  {
    label: '设备',
    field: 'equId',
    component: 'JDictSelectTag',
    componentProps: {
      dictCode: 'dry_equipment,name,id,tenant_id=' + getTenantId(),
    },
  },
  {
    label: '车间',
    field: 'shopId',
    component: 'JDictSelectTag',
    componentProps: {
      dictCode: 'dry_shop,name,id,tenant_id=' + getTenantId(),
    },
  },
  {
    label: '工单状态',
    field: 'orderStatus',
    component: 'InputNumber',
  },
  {
    label: '操作人',
    field: 'operator',
    component: 'JDictSelectTag',
    componentProps: {
      dictCode: 'sys_user,realname,id,tenant_id=' + getTenantId(),
    },
  },
  // TODO 主键隐藏字段，目前写死为ID
  {
    label: '',
    field: 'id',
    component: 'Input',
    show: false,
  },
]

/**
 * 流程表单调用这个方法获取formSchema
 * @param param
 */
export function getBpmFormSchema(_formData): FormSchema[] {
  // 默认和原始表单保持一致 如果流程中配置了权限数据，这里需要单独处理formSchema
  return formSchema
}
